Text.Parsec.Indent
Documentation
block :: (Stream s (StateT SourcePos m) Char, Monad m) => IndentParserT s u m a -> IndentParserT s u m [a]Source
Parses a block of lines at the same indentation level
indents-0.1.0: indentation sensitive parser-combinators for parsec
Text.Parsec.Indent
block :: (Stream s (StateT SourcePos m) Char, Monad m) => IndentParserT s u m a -> IndentParserT s u m [a]Source
Parses a block of lines at the same indentation level